aboutsummaryrefslogtreecommitdiffstats
path: root/core/application.go
diff options
context:
space:
mode:
Diffstat (limited to 'core/application.go')
-rw-r--r--core/application.go6
1 files changed, 4 insertions, 2 deletions
diff --git a/core/application.go b/core/application.go
index edeb686..763954d 100644
--- a/core/application.go
+++ b/core/application.go
@@ -27,8 +27,10 @@ import (
// Application describes the application interface that interacts with DEXON
// consensus core.
type Application interface {
- // TotalOrderingDeliver is called when the total ordering algorithm deliver
- // a set of block.
+ // StronglyAcked is called when a block is strongly acked.
+ StronglyAcked(blockHash common.Hash)
+
+ // TotalOrderingDeliver is called when the total ordering algorithm deliver // a set of block.
TotalOrderingDeliver(blocks []*types.Block, early bool)
// DeliverBlock is called when a block is add to the compaction chain.